function DateAdd(flg,n,nDate,fmt){
//  機能　　　　：指定日の過去または未来の日を求める関数
//  関数名　　　：DateAdd()
//  引数　　　　：flg     "y","m","d"      加算単位（文字属性）
//  　　　　　　：n      ｎ日後またはｎ日前（数値属性）前の時は－値とする
//  　　　　　　：nDate  指定日（文字属性：yyyy/m/d or yyyy/mm/dd）
//  　　　　    ：fmt    戻り値の形式 "yyyy/m/d" "yyyy/mm/dd" "yyyymmdd"
//  戻り値　　　：日付形式（yyyy/m/d）
//
//  呼出例　　　：DatedAdd("d",100,"","yyyy/m/d")  当日の10日後の日付を求める
//  　　　　　　：DatedAdd("d",-25,"2003/1/20","yyyymmdd") 2003/1/20の25日前の日付を求める
//
//  2005/07/20 12月の月末を求める処理修正

    var wDate = convertStr2Date(nDate);
    if (wDate == null){
      return nDate;
    }
    if (isNaN(n)){
      return nDate;
    }

    if (fmt == "yyyy/m/d" || fmt == "yyyy/mm/dd" || fmt == "yyyymmdd"){
      wfmt = fmt;
    }else{
      wfmt = "yyyy/m/d";
    }

    switch (flg.toLowerCase()){
      case "d":
        return DateDAdd(n,formatDate(wDate, "yyyy/m/d"),wfmt);
        break;
      case "m":
        var tYear = wDate.getFullYear();
        var tMonth = wDate.getMonth() + 1 + n;
        var tDate = wDate.getDate();

        if (tMonth == 2 && tDate > 28){
          return DateDAdd(-1,tYear + "/3/1",wfmt)
        }
        if (tMonth == 4 || tMonth == 6 || tMonth == 9 || tMonth == 11){
          if (tDate == 31){
            tDate = 30;
          }
        }
        if (tMonth == 13){
          tYear += 1;
          tMonth = 1;
        }
        if (tMonth < 1){
          tYear -= 1;
          tMonth += 12;
        }

        return formatYMD(wfmt, tYear, tMonth, tDate);
        break;
      case "y":
        var tYear = wDate.getFullYear()+n;
        var tMonth = wDate.getMonth()+1;
        var tDate = wDate.getDate();
        if (tMonth == 2 && tDate > 28){
          return DateDAdd(-1,tYear + "/3/1",wfmt)
        }
        return formatYMD(wfmt, tYear, tMonth, tDate);
        break;
      default:
        return nDate;
        break;
    }
}

function convertStr2Date(nDate) {
//  機能　　　　：年月日をDateに変換する
//  関数　　　　：convertStr2Date()
//　引数  　　　：指定日(文字形式：yyyy/m/d or yyyy/mm/dd）
//  戻り値　　　：指定日のDate、未指定("")時は現在の日付
//             :エラーの場合は、null値が戻ります。

    if (nDate == ""){
      return new Date();
    }
    var wymd = nDate.split("/");
    if (ValidDate(formatYMD("yyyy/mm/dd",wymd[0],wymd[1],wymd[2]))) {
      return new Date(nDate);
    }
    return null;
}

function formatDate(wDate,fmt) {
//  機能　　　　：Dateを指定された形式の文字列に変換する
//  関数　　　　：formatDate()
//　引数  　　　：指定日(Date)
//             :戻り値の形式 "yyyy/m/d" "yyyy/mm/dd" "yyyymmdd"
//  戻り値　　　：指定日の文字列。

    var wY = wDate.getFullYear();
    var wM = wDate.getMonth() + 1;
    var wD = wDate.getDate();
    return formatYMD(fmt, wY, wM, wD);
}

function formatYMD(fmt,tyy,tmm,tdd) {
//  機能　　　　：年月日を指定のフォーマットに変換する
//  関数　　　　：formatYMD()
//　引数  　　　：fmt 戻り値の形式 "yyyy/m/d" "yyyy/mm/dd" "yyyymmdd"
//             :年
//             :月
//             :日
//  戻り値　　　：フォーマット変換した日付文字列

    if (fmt == "yyyy/m/d"){
      return (tyy + "/" + tmm + "/" + tdd);
    }
    var wmm = tmm + "";
    var wdd = tdd + "";
    if (wmm.length == 1){wmm = "0" + wmm};
    if (wdd.length == 1){wdd = "0" + wdd};
    if (fmt == "yyyy/mm/dd"){
      return (tyy + "/" + wmm + "/" + wdd);
    }
    return (tyy + wmm + wdd);
}

function EDate(nDate,fmt){
//  機能　　　　：指定日の月末日を求める
//  関数　　　　：EDate()
//  引数　　　　：指定日(文字形式：yyyy/m/d or yyyy/mm/dd）
//  　　　　：fmt 戻り値の形式 "yyyy/m/d" "yyyy/mm/dd" "yyyymmdd"
//  戻り値　　　：月末日(文字形式：yyyy/m/d）
//
//  2005/07/20 12月の月末を求める処理修正

    var wDate = convertStr2Date(nDate);
    if (wDate == null){
      return nDate;
    }
    if (fmt == "yyyy/m/d" || fmt == "yyyy/mm/dd" || fmt == "yyyymmdd"){
      wfmt = fmt;
    }else{
      wfmt = "yyyy/m/d";
    }

    var tYear = wDate.getFullYear();
    var tMonth = wDate.getMonth() + 2;
    if (tMonth == 13){
      tYear += 1;
      tMonth = 1;
    }
    return DateDAdd(-1,tYear + "/" + tMonth + "/1",wfmt);
}

function DateDAdd(n,nDate,fmt){
//  機能　　　　：指定日にｎ日を加算する
//  関数　　　　：DateDAdd()
//  引数　　　　：加算日数（過去日はマイナス数値)
//  　　　　　　：指定日(文字形式：yyyy/m/d or yyyy/mm/dd）
//       　　　：fmt 戻り値の形式 "yyyy/m/d" "yyyy/mm/dd" "yyyymmdd"
//  戻り値　　　：加算日数した年月日(文字形式：yyyy/m/d）

    var wDate = convertStr2Date(nDate);
    if (wDate == null){
      return nDate;
    }
    if (fmt == "yyyy/m/d" || fmt == "yyyy/mm/dd" || fmt == "yyyymmdd"){
      wfmt = fmt;
    }else{
      wfmt = "yyyy/m/d";
    }

    var wdaysMS = n * 1000 * 60 * 60 * 24;
    var DateMS = wDate.getTime();
    DateMS += wdaysMS;
    wDate.setTime(DateMS);
    return formatDate(wDate, fmt);
}

function ValidDate(dateStr) {
//  機能　　　　：日付の形式、存在チェックを行う
//  関数　　　　：ValidDate()
//  引数　　　　：指定日(文字形式：yyyy/mm/dd）
//  戻り値　　　：エラーのとき、false 、正常なとき、true

    var datePat = /^(\d{4})(\/)(\d{2})\2(\d{2})$/;
    var DateArray = dateStr.match(datePat);
    if (DateArray == null) {
      return false;
    }

    wyear = dateStr.substr(0,4);
    wmonth = eval(dateStr.substr(5,2));
    wday = eval(dateStr.substr(8,2));

    if (!mon_chk(wmonth)){
      return false;
    }

    dd = daymonth(wyear,wmonth);
    if (wday > dd){
      return false;
    }

    return true;
}

/* 日付の範囲チェック */
function daymonth(year,month){
    day = new Array(31,28,31,30,31,30,31,31,30,31,30,31);
    if(month==2 && leapyear(year)) return 29;
    return day[month-1];
}
/* うるう年のチェック */
function leapyear(year){
    return year%4==0 && (year%100!=0 || year%400==0);
}

/* 月の範囲チェック */
function mon_chk(month){
    if((month >= 1) && (month <= 12)) return true;
    return false;
}

function ValidTime(timeStr) {
//  機能　　　　：時刻の形式、存在チェックを行う
//  関数　　　　：ValidTime()
//  引数　　　　：指定日(文字形式：hh:mm:ss）
//  戻り値　　　：エラーのとき、false 、正常なとき、true

    var timePat = /^([012][0-9])(\:)([0-5][0-9])\2([0-5][0-9])$/;
    var TimeArray = timeStr.match(timePat);
    if (TimeArray == null) {
      return false;
    }

    whh = timeStr.substr(0,2);
    wmm = eval(timeStr.substr(3,2));
    wss = eval(timeStr.substr(6,2));
    if (whh > "23" || wmm > "59" || wss > "59") {
      return false;
    }

    return true;
}

function getWeek(oDate){
//  機能　　　　：指定日の曜日を戻す
//  関数　　　　：getWeek()
//  引数　　　　：指定日(文字形式：yyyy/mm/dd or yyyy/m/d）
//  戻り値　　　：指定日の曜日を"(月)"形式で戻す

    var yobi = new Array("日","月","火","水","木","金","土");
    var wDate = convertStr2Date(oDate);
    if (wDate == null){
      return "";
    }
    var wdy = "（" + yobi[wDate.getDay()] + "）";
    return wdy;
}


function separatesDt(sDate){
//  機能　　　　：指定日を 年、月、日で分割して返す
//  関数　　　　：separatesDt()
//  引数　　　　：指定日(文字形式：yyyy/mm/dd or yyyy/m/d）
//  戻り値　　　：指定日を年、月、日で分割して返す fDate[0] = yyyy, fDate[1]=m , fDate[2] = d
	var fDate =sDate.replace("/0","/");
	fDate =fDate.split("/"); 
	return fDate;
}

